pub struct Alignment {
pub score: f32,
pub positions: Vec<AlignedPosition>,
pub cons_start: u8,
pub cons_end: u8,
pub confidence_score: f32,
pub max_confidence_score: f32,
pub query_start: usize,
pub query_end: usize,
}Expand description
Result of aligning a sequence to a consensus
Fields
score: f32Alignment score
positions: Vec<AlignedPosition>Aligned positions (length == query length; flanking residues are Insertion())
cons_start: u8First aligned consensus position (IMGT position number)
cons_end: u8Last aligned consensus position (IMGT position number)
confidence_score: f32Sum of scores at confidence-relevant positions (occupancy > 0.5)
max_confidence_score: f32Sum of max possible scores at confidence-relevant positions
query_start: usize0-based index of the first antibody residue in the query (0 when no prefix)
query_end: usize0-based index of the last antibody residue in the query (query.len()-1 when no suffix)